@@ -14,35 +14,16 @@
 
 
 
-#' @title S3 Method Dispatches to `'add_'` Class
+#' @title [sort_by.add_]
 #' 
 #' @param x an object returned from functions 
-#' [add_dummy_partition()], [add_dummy()] or [add_num()]
+#' [add_dummy_partition()], [add_dummy()] or [add_numeric()]
 #' 
 #' @param y \link[base]{language}, see function \link[base]{sort_by}
 #' 
 #' @param ... additional parameters of S3 generic \link[base]{sort_by}, etc.
 #' 
 #' @details
-#' ..
-#' 
-#' @returns
-#' Function [print.add_] does not have a returned value
-#' 
-#' @name S3_add_
-#' @keywords internal
-#' @export print.add_
-#' @export
-print.add_ <- function(x, ...) {
-  cat(names(x), sep = '\n')
-  return(invisible())
-}
-
-
-
-#' @rdname S3_add_
-#' 
-#' @details
 #' Function [sort_by.add_()] sorts the elements of an `'add_'` object by a certain criterion `y`.
 #' We suggest using `y = abc(effsize)` and `decreasing = TRUE` order of the \link[base]{abs}olute values of the effect sizes of additional predictor.  
 #'
@@ -54,7 +35,9 @@ print.add_ <- function(x, ...) {
 #' @export
 sort_by.add_ <- function(x, y, ...) {
   effsize <- vapply(x, FUN = attr, which = 'effsize', exact = TRUE, FUN.VALUE = NA_real_)
-  o <- substitute(y) |> eval() |> order(...) # ?base::order
+  o <- substitute(y) |> 
+    eval() |> 
+    order(...) # ?base::order
   x[o]
 }
 
